import { select, 
        json, 
        tsv, 
        geoPath, 
        geoNaturalEarth1, 
        zoom,
        event } from 'd3';
import { feature } from 'topojson';
import { loadAndProcessData} from './loadAndProcessData';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');

const projection = geoNaturalEarth1()
			.clipExtent([[0,0],[width,height]]);

const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

g.append('path')
	.attr('class', 'sphere')
	.attr('d', pathGenerator({type:'Sphere'}))

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

loadAndProcessData().then(countries => {
  const paths = svg.selectAll('path')
  	.data(countries.features)
  
  paths.enter().append('path')
  	.attr('class', 'country')
  	.attr('d', d => pathGenerator(d))
  .append('title')
  	.text(d => d.properties.name);
});

// json('https://cdn.jsdelivr.net/npm/world-atlas@2.0.2/countries-10m.json')
//   .then(topoJsonData => {
// const countries = feature(topoJsonData, topoJsonData.objects.countries);			
//   const paths = g.selectAll('path')
//     .data(countries.features)
//   paths.enter().append('path')
//     .attr('class', 'country')
//     .attr('d', d => pathGenerator(d))
//   .append('title')
//     .text(d => d.properties.name);
// });
// //d.properties.name for new world atlas data        